#include "pickselectoraction.h"
#include <QDebug>

#ifdef Q_WS_MAEMO_5
    #include <QMaemo5ListPickSelector>
    #include <QMaemo5ValueButton>
#endif

PickSelectorAction::PickSelectorAction(QStringList list, int selIndex, QObject *parent) :
    QWidgetAction(parent)
{
    m_pModel = NULL;
    m_items = list;
    m_selectedIndex = selIndex;
}

PickSelectorAction::PickSelectorAction(QObject *parent) :
    QWidgetAction(parent),
    m_selectedIndex(0)
{
    m_pModel = NULL;
}

PickSelectorAction::~PickSelectorAction() {
    if ( m_pModel ) { delete m_pModel; m_pModel = NULL; }
}

QWidget* PickSelectorAction::createWidget(QWidget *parent) {
#ifdef Q_WS_MAEMO_5
    if ( m_pModel ) {  delete m_pModel; m_pModel = NULL; }
    m_pModel = new QStringListModel(this);
    m_pModel->setStringList(m_items);

    QMaemo5ListPickSelector *selector = new QMaemo5ListPickSelector(parent);
    selector->setModel(m_pModel);
    selector->setCurrentIndex(m_selectedIndex);

    QMaemo5ValueButton *valueButton = new QMaemo5ValueButton(text(), parent);
    // Maemo5 style guide wants the menu entries centered.
    valueButton->setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered);
    valueButton->setPickSelector(selector);

    connect(selector, SIGNAL(selected(const QString &)), this, SLOT(optionSelected(const QString &)));

    return valueButton;
#else
    Q_UNUSED(parent)
    qDebug() << "PickSelectorAction::createWidget not supported";
    return NULL;
#endif
}

void PickSelectorAction::optionSelected(const QString& str) {
    int index = -1;
    for ( int c=0; c<m_items.size(); c++ ){
        if ( m_items.at(c) == str ) {
            index =c;
            break;
        }
    }

    if (index<0){
        qDebug() << "Not find item...how?";
        return;
    }

    qDebug() << "Item Selected: " << str << ", index=" << QString::number(index);
    m_selectedIndex = index;
    selectionChanged(m_selectedIndex);
}

QStringList& PickSelectorAction::items() {
    return m_items;
}

void PickSelectorAction::setSelectedIndex(int index) {
    if (index<0 || index>=m_items.size() ) return;
    m_selectedIndex = index;
}

int PickSelectorAction::selectedIndex() {
    return m_selectedIndex;
}
